# pytorch-iga

## Quick start

```bash
pip install pytorch-iga
```

```python
from iga import ...
```

## Contributing

```bash
# clone the repo
git clone https://github.com/phitoduck/pytorch-iga.git

# install the dev dependencies
make install

# run the tests
make test
```
